@@ -3,9 +3,9 @@
  *     This file is part of cdargs
  *
  *     Copyright (C) 2001-2003 by Stefan Kamphausen
- *     Author: Stefan Kamphausen <mail@skamphausen.de>
+ *     Author: Stefan Kamphausen <http://www.skamphausen.de>
  *
- *     Time-stamp: <31-Dec-2004 00:24:13 ska>
+ *     Time-stamp: <09-Oct-2005 12:41:36 ska>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -1246,7 +1246,7 @@ void helpscreen(void) {
    
     int l = 0;
     char* help_lines[] = {
-        "cdargs (c) 2001-2003 S. Kamphausen <mail@skamphausen.de>",
+        "cdargs (c) 2001-2003 S. Kamphausen <http://www.skamphausen.de>",
         "<UP>/<DOWN>  move selection up/down and scroll",
         "             please see manpage for alternative bindings!",
         "<ENTER>      select current entry",
@@ -1309,7 +1309,7 @@ void terminate(int sig) {
         fprintf(stderr,"programm received signal %d\n",sig);
         fprintf(stderr,"This should never happen.\n");
         fprintf(stderr,"Maybe you want to send an email to the author and report a bug?\n");
-        fprintf(stderr,"Author: Stefan Kamphausen <mail@skamphausen.de>\n"); 
+        fprintf(stderr,"Author: Stefan Kamphausen <http://www.skamphausen.de>\n"); 
     }
     fprintf(stderr,"abort.\n");
     exit(1);
